<?php

class modelGuestbook extends cmsModel {

    public function addGuestbookItem($items) {

        $items['id'] = $this->insert('guestbook_items', $items);

        return $items;
    }

    public function getGuestbookItems($message_len = 0) {

        if ($message_len > 0) {
            // Укорачиваем сообщения до заданной длинны
            return $this->get('guestbook_items', function($item) use ($message_len) {
                        $item['text'] = html_clean($item['text'], $message_len);
                        return $item;
                    });
        } else {
            // Возвращаем строки без обработки
            return $this->get('guestbook_items');
        }
    }

    public function getGuestbookFullItem($id) {


        $this->joinUser('user_id', array(), 'left');

        $item = $this->getItemById('guestbook_items', $id);

        $item['rep'] = $this->filterEqual('is_approved', 1)->getGuestbookRepItems($item['id']);

        return $item;
    }

    public function getGuestbookFullItems() {

        $this->joinUser('user_id', array(), 'left');

        $items = $this->get('guestbook_items', function($item, $model) {

            $item['rep'] = $model->filterEqual('is_approved', 1)->getGuestbookRepItems($item['id']);

            return $item;
        });

        return $items;
    }

    public function itemsGuestbookTotal() {

        return $this->getCount('guestbook_items');
    }

    public function deleteGuestbookItem($id) {

        return $this->delete('guestbook_items', $id);
    }

    public function updateGuestbookItem($id, $item) {

        return $this->update('guestbook_items', $id, $item);
    }

    public function getGuestbookItemField($value, $field_name) {

        $this->filterEqual($field_name, $value);

        return $this->getItem('guestbook_items');
    }

    public function getGuestbookItem($id) {

        if (is_numeric($id)) {

            return $this->getItemById('guestbook_items',$id);

            } else {

            $id = str_replace(".html", "", $id);

            $this->filterEqual('slug', $id);
        }
        $this->joinUser();

        return $this->getItem('guestbook_items');
    }

    public function approvGuestbookItem($id) {

        return $this->update('guestbook_items', $id, array(
                    'is_approved' => 1
        ));
    }

    public function getGuestbookRepItems($rep_id) {

        $this->joinUser();

        return $this->filterEqual('rep_id', $rep_id)->orderBy('date_pub', 'asc')->
                        get('guestbook_items');
    }

    public function getGuestbookItemSlug($item, $check_slug = true) {

        $url_pattern = empty($this->config['url_pattern']) ? '{id}-{title}' : $this->config['url_pattern'];

        $slug_len = 100;
        $matches = array();
        $pattern = trim($url_pattern, '/');

        preg_match_all('/{([a-z0-9\_]+)}/i', $pattern, $matches);

        if (!$matches) {
            return lang_slug($item['id']);
        }

        list($tags, $names) = $matches;

        foreach ($names as $idx => $field_name) {

            if (!empty($item[$field_name])) {

                $value = str_replace('/', '', $item[$field_name]);

                if ($field_name == 'type' && !empty($this->config['types'])) {
                    $value = $this->config['types'][$value];
                    $value = trim($value, '/');
                }

                $pattern = str_replace($tags[$idx], $value, $pattern);
            }
        }

        $slug = lang_slug($pattern);

        $slug = mb_substr($slug, 0, $slug_len);

        if (!$check_slug) {
            return $slug;
        }

        if ($this->filterNotEqual('id', $item['id'])->
                        filterEqual('slug', $slug)->
                        getFieldFiltered('guestbook_items', 'id')) {

            $id_len = strlen((string) $item['id']) + 1;

            $slug = mb_substr($slug, 0, ($slug_len - $id_len));
            $slug .= '-' . $item['id'];
        }

        return $slug;
    }

    public function deleteController($id) {

        $this->delete('widgets', 'name = "guestbooknow"');

        $this->delete('menu_items', 'url = "guestbook"');

        $this->db->query('DROP TABLE {#}guestbook_items');

        $this->delete('scheduler_tasks', 'guestbook', 'controller');

        $this->delete('perms_rules', 'guestbook', 'controller');

        $this->delete('perms_users', 'guestbook', 'subject');

        return parent::deleteController($id);
    }

}
